#ifndef NT2_INCLUDE_FUNCTIONS_IF_ALLBITS_ELSE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IF_ALLBITS_ELSE_HPP_INCLUDED

#include <nt2/boolean/include/functions/if_allbits_else.hpp>

#endif
